==> xlr-vsts-tfs-plugin-7.5.0.jar: vsts/QueueBuild.wait-for-build-to-finish.py <==
#
# Copyright 2017 XEBIALABS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from vsts import TfsServer

tfsServer = TfsServer(tfsServer)
buildStatus = tfsServer.getBuildStatus(teamProjectName, buildId)

if buildStatus != "completed":
    task.schedule("vsts/QueueBuild.wait-for-build-to-finish.py")
else:
    buildResult = tfsServer.getBuildResult(teamProjectName, buildId)
    buildNumber = tfsServer.getBuildNumber(teamProjectName, buildId)
    
    if buildResult != "succeeded":
        raise Exception("Build failed with status '%s'" % buildResult)

==> xlr-vsts-tfs-plugin-10.3.0-817.113.jar: vsts/QueueBuild.wait-for-build-to-finish.py <==
#
# Copyright 2017 XEBIALABS
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the "Software"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from vsts import TfsServer

tfsServer = TfsServer(tfsServer, overrideUsername, overridePassword, overrideDomain)
buildStatus = tfsServer.getBuildStatus(teamProjectName, buildId)

if buildStatus != "completed":
    task.schedule("vsts/QueueBuild.wait-for-build-to-finish.py")
else:
    buildResult = tfsServer.getBuildResult(teamProjectName, buildId)
    buildNumber = tfsServer.getBuildNumber(teamProjectName, buildId)
    
    if buildResult != "succeeded":
        raise Exception("Build failed with status '%s'" % buildResult)
